==> rxode2parse_2.0.12.tar.gz: rxode2parse/R/dfIni.R <==
.parseEnv$.rxode2parseDf <-  structure(list(rxFun = c("linCmtA", "linCmtB", "linCmtC", "rxnorm", 
"rxbinom", "rxnbinom", "rxnbinomMu", "rxcauchy", "rxchisq", "rxexp", 
"rxf", "rxgeom", "rxgamma", "rxbeta", "rxpois", "rxt_", "rxunif", 
"rxweibull", "rinorm", "ribinom", "rinbinom", "rinbinomMu", "ricauchy", 
"richisq", "riexp", "rif", "rigeom", "rigamma", "ribeta", "ripois", 
"rit_", "riunif", "riweibull", "phi", "gammap", "gammaq", "gammapInv", 
"gammapInva", "gammaqInv", "gammaqInva", "uppergamma", "lowergamma", 
"gammapDer", "logit", "expit", "simeta", "simeps", "llikNorm", 
"llikNormDmean", "llikNormDsd", "llikPois", "llikPoisDlambda", 
"llikBinom", "llikBinomDprob", "llikNbinom", "llikNbinomDprob", 
"llikNbinomMu", "llikNbinomMuDmu", "llikBeta", "llikBetaDshape1", 
"llikBetaDshape2", "llikT", "llikTDdf", "llikTDmean", "llikTDsd", 
"llikChisq", "llikChisqDdf", "llikExp", "llikExpDrate", "llikF", 
"llikFDdf1", "llikFDdf2", "llikGeom", "llikGeomDp", "llikUnif", 
"llikUnifDalpha", "llikUnifDbeta", "llikWeibull", "llikWeibullDshape", 
"llikWeibullDscale", "llikGamma", "llikGammaDshape", "llikGammaDrate", 
"llikCauchy", "llikCauchyDlocation", "llikCauchyDscale"), fun = c("linCmtA", 
"linCmtB", "linCmtC", "rxnorm", "rxbinom", "rxnbinom", "rxnbinomMu", 
"rxcauchy", "rxchisq", "rxexp", "rxf", "rxgeom", "rxgamma", "rxbeta", 
"rxpois", "rxt_", "rxunif", "rxweibull", "rinorm", "ribinom", 
"rinbinom", "rinbinomMu", "ricauchy", "richisq", "riexp", "rif", 
"rigeom", "rigamma", "ribeta", "ripois", "rit_", "riunif", "riweibull", 
"phi", "gammap", "gammaq", "gammapInv", "gammapInva", "gammaqInv", 
"gammaqInva", "uppergamma", "lowergamma", "gammapDer", "logit", 
"expit", "simeta", "simeps", "_llikNorm", "_llikNormDmean", "_llikNormDsd", 
"_llikPois", "_llikPoisDlambda", "_llikBinom", "_llikBinomDprob", 
"_llikNbinom", "_llikNbinomDprob", "_llikNbinomMu", "_llikNbinomMuDmu", 
"_llikBeta", "_llikBetaDshape1", "_llikBetaDshape2", "_llikT", 
"_llikTDdf", "_llikTDmean", "_llikTDsd", "_llikChisq", "_llikChisqDdf", 
"_llikExp", "_llikExpDrate", "_llikF", "_llikFDdf1", "_llikFDdf2", 
"_llikGeom", "_llikGeomDp", "_llikUnif", "_llikUnifDalpha", "_llikUnifDbeta", 
"_llikWeibull", "_llikWeibullDshape", "_llikWeibullDscale", "_llikGamma", 
"_llikGammaDshape", "_llikGammaDrate", "_llikCauchy", "_llikCauchyDlocation", 
"_llikCauchyDscale"), type = c("linCmtA_p", "linCmtB_p", "linCmtA_p", 
"rxode2i_fn2", "rxode2i_rxbinom", "rxode2i_rxbinom", "rxode2i_rxbinom", 
"rxode2i_fn2", "rxode2i_fn", "rxode2i_fn", "rxode2i_fn2", "rxode2i_ifn", 
"rxode2i_fn2", "rxode2i_fn2", "rxode2i_ifn", "rxode2i_fn", "rxode2i_fn2", 
"rxode2i_fn2", "rxode2i2_fn2", "rxode2i2_ribinom", "rxode2i2_ribinom", 
"rxode2i2_ribinom", "rxode2i2_fn2", "rxode2i2_fn", "rxode2i2_fn", 
"rxode2i2_fn2", "rxode2i2_ifn", "rxode2i2_fn2", "rxode2i2_fn2", 
"rxode2i2_ifn", "rxode2i2_fn", "rxode2i2_fn2", "rxode2i2_fn2", 
"rxode2_fn", "rxode2_fn2", "rxode2_fn2", "rxode2_fn2", "rxode2_fn2", 
"rxode2_fn2", "rxode2_fn2", "rxode2_fn2", "rxode2_fn2", "rxode2_fn2", 
"rxode2_fn3", "rxode2_fn3", "_simfun", "_simfun", "rxode2_llikNormFun", 
"rxode2_llikNormFun", "rxode2_llikNormFun", "rxode2_llikPoisFun", 
"rxode2_llikPoisFun", "rxode2_llikBinomFun", "rxode2_llikBinomFun", 
"rxode2_llikBinomFun", "rxode2_llikBinomFun", "rxode2_llikBinomFun", 
"rxode2_llikBinomFun", "rxode2_llikBetaFun", "rxode2_llikBetaFun", 
"rxode2_llikBetaFun", "rxode2_llikTFun", "rxode2_llikTFun", "rxode2_llikTFun", 
"rxode2_llikTFun", "rxode2_llikChisqFun", "rxode2_llikChisqFun", 
"rxode2_llikExpFun", "rxode2_llikExpFun", "rxode2_llikFFun", 
"rxode2_llikFFun", "rxode2_llikFFun", "rxode2_llikGeomFun", "rxode2_llikGeomFun", 
"rxode2_llikUnifFun", "rxode2_llikUnifFun", "rxode2_llikUnifFun", 
"rxode2_llikWeibullFun", "rxode2_llikWeibullFun", "rxode2_llikWeibullFun", 
"rxode2_llikGammaFun", "rxode2_llikGammaFun", "rxode2_llikGammaFun", 
"rxode2_llikCauchyFun", "rxode2_llikCauchyFun", "rxode2_llikCauchyFun"
), package = c("rxode2parse", "rxode2parse", "rxode2parse", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2", "rxode2", "rxode2", 
"rxode2", "rxode2", "rxode2", "rxode2", "rxode2", "rxode2", "rxode2", 
"rxode2", "rxode2random", "rxode2random", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll"), packageFun = c("linCmtA", "linCmtB", "linCmtC", 
"rxnorm", "rxbinom", "rxnbinom", "rxnbinomMu", "rxcauchy", "rxchisq", 
"rxexp", "rxf", "rxgeom", "rxgamma", "rxbeta", "rxpois", "rxt_", 
"rxunif", "rxweibull", "rinorm", "ribinom", "rinbinom", "rinbinomMu", 
"ricauchy", "richisq", "riexp", "rif", "rigeom", "rigamma", "ribeta", 
"ripois", "rit_", "riunif", "riweibull", "phi", "gammap", "gammaq", 
"gammapInv", "gammapInva", "gammaqInv", "gammaqInva", "uppergamma", 
"lowergamma", "gammapDer", "logit", "expit", "simeta", "simeps", 
"rxLlikNorm", "rxLlikNormDmean", "rxLlikNormDsd", "rxLlikPois", 
"rxLlikPoisDlambda", "rxLlikBinom", "rxLlikBinomDprob", "rxLlikNbinom", 
"rxLlikNbinomDprob", "rxLlikNbinomMu", "rxLlikNbinomMuDmu", "rxLlikBeta", 
"rxLlikBetaDshape1", "rxLlikBetaDshape2", "rxLlikT", "rxLlikTDdf", 
"rxLlikTDmean", "rxLlikTDsd", "rxLlikChisq", "rxLlikChisqDdf", 
"rxLlikExp", "rxLlikExpDrate", "rxLlikF", "rxLlikFDdf1", "rxLlikFDdf2", 
"rxLlikGeom", "rxLlikGeomDp", "rxLlikUnif", "rxLlikUnifDalpha", 
"rxLlikUnifDbeta", "rxLlikWeibull", "rxLlikWeibullDshape", "rxLlikWeibullDscale", 
"rxLlikGamma", "rxLlikGammaDshape", "rxLlikGammaDrate", "rxLlikCauchy", 
"rxLlikCauchyDlocation", "rxLlikCauchyDscale"), argMin = c(NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_
), argMax = c(NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_, NA_integer_, NA_integer_, NA_integer_, 
NA_integer_, NA_integer_), threadSafe = c(1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L)), row.names = c(NA, -86L), class = "data.frame")

==> rxode2parse_2.0.16.tar.gz: rxode2parse/R/dfIni.R <==
.parseEnv$.rxode2parseDf <-  structure(list(rxFun = c("linCmtA", "linCmtB", "linCmtC", "rxnorm", 
"rxbinom", "rxnbinom", "rxnbinomMu", "rxcauchy", "rxchisq", "rxexp", 
"rxf", "rxgeom", "rxgamma", "rxbeta", "rxpois", "rxt_", "rxunif", 
"rxweibull", "rinorm", "ribinom", "rinbinom", "rinbinomMu", "ricauchy", 
"richisq", "riexp", "rif", "rigeom", "rigamma", "ribeta", "ripois", 
"rit_", "riunif", "riweibull", "phi", "gammap", "gammaq", "gammapInv", 
"gammapInva", "gammaqInv", "gammaqInva", "uppergamma", "lowergamma", 
"gammapDer", "logit", "expit", "simeta", "simeps", "llikNorm", 
"llikNormDmean", "llikNormDsd", "llikPois", "llikPoisDlambda", 
"llikBinom", "llikBinomDprob", "llikNbinom", "llikNbinomDprob", 
"llikNbinomMu", "llikNbinomMuDmu", "llikBeta", "llikBetaDshape1", 
"llikBetaDshape2", "llikT", "llikTDdf", "llikTDmean", "llikTDsd", 
"llikChisq", "llikChisqDdf", "llikExp", "llikExpDrate", "llikF", 
"llikFDdf1", "llikFDdf2", "llikGeom", "llikGeomDp", "llikUnif", 
"llikUnifDalpha", "llikUnifDbeta", "llikWeibull", "llikWeibullDshape", 
"llikWeibullDscale", "llikGamma", "llikGammaDshape", "llikGammaDrate", 
"llikCauchy", "llikCauchyDlocation", "llikCauchyDscale"), fun = c("linCmtA", 
"linCmtB", "linCmtC", "rxnorm", "rxbinom", "rxnbinom", "rxnbinomMu", 
"rxcauchy", "rxchisq", "rxexp", "rxf", "rxgeom", "rxgamma", "rxbeta", 
"rxpois", "rxt_", "rxunif", "rxweibull", "rinorm", "ribinom", 
"rinbinom", "rinbinomMu", "ricauchy", "richisq", "riexp", "rif", 
"rigeom", "rigamma", "ribeta", "ripois", "rit_", "riunif", "riweibull", 
"phi", "gammap", "gammaq", "gammapInv", "gammapInva", "gammaqInv", 
"gammaqInva", "uppergamma", "lowergamma", "gammapDer", "logit", 
"expit", "simeta", "simeps", "_llikNorm", "_llikNormDmean", "_llikNormDsd", 
"_llikPois", "_llikPoisDlambda", "_llikBinom", "_llikBinomDprob", 
"_llikNbinom", "_llikNbinomDprob", "_llikNbinomMu", "_llikNbinomMuDmu", 
"_llikBeta", "_llikBetaDshape1", "_llikBetaDshape2", "_llikT", 
"_llikTDdf", "_llikTDmean", "_llikTDsd", "_llikChisq", "_llikChisqDdf", 
"_llikExp", "_llikExpDrate", "_llikF", "_llikFDdf1", "_llikFDdf2", 
"_llikGeom", "_llikGeomDp", "_llikUnif", "_llikUnifDalpha", "_llikUnifDbeta", 
"_llikWeibull", "_llikWeibullDshape", "_llikWeibullDscale", "_llikGamma", 
"_llikGammaDshape", "_llikGammaDrate", "_llikCauchy", "_llikCauchyDlocation", 
"_llikCauchyDscale"), type = c("linCmtA_p", "linCmtB_p", "linCmtA_p", 
"rxode2i_fn2", "rxode2i_rxbinom", "rxode2i_rxbinom", "rxode2i_rxbinom", 
"rxode2i_fn2", "rxode2i_fn", "rxode2i_fn", "rxode2i_fn2", "rxode2i_ifn", 
"rxode2i_fn2", "rxode2i_fn2", "rxode2i_ifn", "rxode2i_fn", "rxode2i_fn2", 
"rxode2i_fn2", "rxode2i2_fn2", "rxode2i2_ribinom", "rxode2i2_ribinom", 
"rxode2i2_ribinom", "rxode2i2_fn2", "rxode2i2_fn", "rxode2i2_fn", 
"rxode2i2_fn2", "rxode2i2_ifn", "rxode2i2_fn2", "rxode2i2_fn2", 
"rxode2i2_ifn", "rxode2i2_fn", "rxode2i2_fn2", "rxode2i2_fn2", 
"rxode2_fn", "rxode2_fn2", "rxode2_fn2", "rxode2_fn2", "rxode2_fn2", 
"rxode2_fn2", "rxode2_fn2", "rxode2_fn2", "rxode2_fn2", "rxode2_fn2", 
"rxode2_fn3", "rxode2_fn3", "_simfun", "_simfun", "rxode2_llikNormFun", 
"rxode2_llikNormFun", "rxode2_llikNormFun", "rxode2_llikPoisFun", 
"rxode2_llikPoisFun", "rxode2_llikBinomFun", "rxode2_llikBinomFun", 
"rxode2_llikBinomFun", "rxode2_llikBinomFun", "rxode2_llikBinomFun", 
"rxode2_llikBinomFun", "rxode2_llikBetaFun", "rxode2_llikBetaFun", 
"rxode2_llikBetaFun", "rxode2_llikTFun", "rxode2_llikTFun", "rxode2_llikTFun", 
"rxode2_llikTFun", "rxode2_llikChisqFun", "rxode2_llikChisqFun", 
"rxode2_llikExpFun", "rxode2_llikExpFun", "rxode2_llikFFun", 
"rxode2_llikFFun", "rxode2_llikFFun", "rxode2_llikGeomFun", "rxode2_llikGeomFun", 
"rxode2_llikUnifFun", "rxode2_llikUnifFun", "rxode2_llikUnifFun", 
"rxode2_llikWeibullFun", "rxode2_llikWeibullFun", "rxode2_llikWeibullFun", 
"rxode2_llikGammaFun", "rxode2_llikGammaFun", "rxode2_llikGammaFun", 
"rxode2_llikCauchyFun", "rxode2_llikCauchyFun", "rxode2_llikCauchyFun"
), package = c("rxode2parse", "rxode2parse", "rxode2parse", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2random", "rxode2random", 
"rxode2random", "rxode2random", "rxode2", "rxode2", "rxode2", 
"rxode2", "rxode2", "rxode2", "rxode2", "rxode2", "rxode2", "rxode2", 
"rxode2", "rxode2random", "rxode2random", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", "rxode2ll", 
"rxode2ll"), packageFun = c("linCmtA", "linCmtB", "linCmtC", 
"rxnorm", "rxbinom", "rxnbinom", "rxnbinomMu", "rxcauchy", "rxchisq", 
"rxexp", "rxf", "rxgeom", "rxgamma", "rxbeta", "rxpois", "rxt_", 
"rxunif", "rxweibull", "rinorm", "ribinom", "rinbinom", "rinbinomMu", 
"ricauchy", "richisq", "riexp", "rif", "rigeom", "rigamma", "ribeta", 
"ripois", "rit_", "riunif", "riweibull", "phi", "gammap", "gammaq", 
"gammapInv", "gammapInva", "gammaqInv", "gammaqInva", "uppergamma", 
"lowergamma", "gammapDer", "logit", "expit", "simeta", "simeps", 
"rxLlikNorm", "rxLlikNormDmean", "rxLlikNormDsd", "rxLlikPois", 
"rxLlikPoisDlambda", "rxLlikBinom", "rxLlikBinomDprob", "rxLlikNbinom", 
"rxLlikNbinomDprob", "rxLlikNbinomMu", "rxLlikNbinomMuDmu", "rxLlikBeta", 
"rxLlikBetaDshape1", "rxLlikBetaDshape2", "rxLlikT", "rxLlikTDdf", 
"rxLlikTDmean", "rxLlikTDsd", "rxLlikChisq", "rxLlikChisqDdf", 
"rxLlikExp", "rxLlikExpDrate", "rxLlikF", "rxLlikFDdf1", "rxLlikFDdf2", 
"rxLlikGeom", "rxLlikGeomDp", "rxLlikUnif", "rxLlikUnifDalpha", 
"rxLlikUnifDbeta", "rxLlikWeibull", "rxLlikWeibullDshape", "rxLlikWeibullDscale", 
"rxLlikGamma", "rxLlikGammaDshape", "rxLlikGammaDrate", "rxLlikCauchy", 
"rxLlikCauchyDlocation", "rxLlikCauchyDscale"), argMin = c(20L, 
21L, 20L, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
NA, NA, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, 2L, NA, NA, NA, NA, 3L, 
3L, 3L, 2L, 2L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 4L, 4L, 4L, 
4L, 2L, 2L, 2L, 2L, 3L, 3L, 3L, 2L, NA, 3L, 3L, 3L, 3L, 3L, 3L, 
3L, 3L, 3L, 3L, 3L, 3L), argMax = c(20L, 21L, 20L, NA, NA, NA, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 2L, 2L, 2L, 2L, 
2L, 2L, 2L, 2L, 2L, NA, NA, NA, NA, 3L, 3L, 3L, 2L, 2L, 3L, 3L, 
3L, 3L, 3L, 3L, 3L, 3L, 3L, 4L, 4L, 4L, 4L, 2L, 2L, 2L, 2L, 3L, 
3L, 3L, 2L, NA, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L, 3L
), threadSafe = c(1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L)), row.names = c(NA, 
-86L), class = "data.frame")
